/* ANSI-C code produced by gperf version 3.3 */
/* Command-line: gperf --output-file src/network/netdev-gperf.c ../systemd/src/network/netdev/netdev-gperf.gperf  */
/* Computed positions: -k'2,5-6,8-9,14-15,18,20-21,23-24' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
#endif

#line 2 "../systemd/src/network/netdev/netdev-gperf.gperf"

_Pragma("GCC diagnostic ignored \"-Wimplicit-fallthrough\"")
#if __GNUC__ >= 15
_Pragma("GCC diagnostic ignored \"-Wzero-as-null-pointer-constant\"")
#endif
#include <stddef.h>
#include "bareudp.h"
#include "batadv.h"
#include "bond.h"
#include "bridge.h"
#include "condition.h"
#include "conf-parser.h"
#include "fou-tunnel.h"
#include "geneve.h"
#include "hsr.h"
#include "ipoib.h"
#include "ipvlan.h"
#include "l2tp-tunnel.h"
#include "macsec.h"
#include "macvlan.h"
#include "net-condition.h"
#include "netdev.h"
#include "tunnel.h"
#include "tuntap.h"
#include "veth.h"
#include "vlan-util.h"
#include "vlan.h"
#include "vrf.h"
#include "vxcan.h"
#include "vxlan.h"
#include "wireguard.h"
#include "wlan.h"
#include "xfrm.h"
#include <string.h>

#define TOTAL_KEYWORDS 245
#define MIN_WORD_LENGTH 7
#define MAX_WORD_LENGTH 40
#define MIN_HASH_VALUE 8
#define MAX_HASH_VALUE 687
/* maximum key range = 680, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
network_netdev_gperf_hash (register const char *str, register size_t len)
{
  static const unsigned short asso_values[] =
    {
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688,  10, 688, 688, 688,
      110,   5, 688, 688,  75, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688,   0,  65, 150,   0,   0,
      145, 145, 195, 160, 688,  45,  45,  30,   0,  84,
       20,  45,  15,  50,  40,   0,  85,   5,   5, 688,
      688, 688, 688, 688, 688, 688, 688,   0,  35,   5,
       15,   0,  30,  35, 200,   0, 688, 100,  60,  55,
        5,   0, 170, 688,   0,   0,   5,  10,   0,  65,
      200, 185,   0, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688, 688, 688, 688, 688,
      688, 688, 688, 688, 688, 688
    };
  register unsigned int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[23]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 23:
        hval += asso_values[(unsigned char)str[22]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 22:
      case 21:
        hval += asso_values[(unsigned char)str[20]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 20:
        hval += asso_values[(unsigned char)str[19]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 19:
      case 18:
        hval += asso_values[(unsigned char)str[17]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 17:
      case 16:
      case 15:
        hval += asso_values[(unsigned char)str[14]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 14:
        hval += asso_values[(unsigned char)str[13]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 13:
      case 12:
      case 11:
      case 10:
      case 9:
        hval += asso_values[(unsigned char)str[8]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 8:
        hval += asso_values[(unsigned char)str[7]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 7:
      case 6:
        hval += asso_values[(unsigned char)str[5]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 5:
        hval += asso_values[(unsigned char)str[4]];
#if (defined __cplusplus && (__cplusplus >= 201703L || (__cplusplus >= 201103L && defined __clang__ && __clang_major__ + (__clang_minor__ >= 9) > 3))) || (defined __STDC_VERSION__ && __STDC_VERSION__ >= 202000L && ((defined __GNUC__ && __GNUC__ >= 10) || (defined __clang__ && __clang_major__ >= 9)))
      [[fallthrough]];
#elif (defined __GNUC__ && __GNUC__ >= 7) || (defined __clang__ && __clang_major__ >= 10)
      __attribute__ ((__fallthrough__));
#endif
      /*FALLTHROUGH*/
      case 4:
      case 3:
      case 2:
        hval += asso_values[(unsigned char)str[1]];
        break;
    }
  return hval;
}

const struct ConfigPerfItem *
network_netdev_gperf_lookup (register const char *str, register size_t len)
{
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif
  static const struct ConfigPerfItem wordlist[] =
    {
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 208 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.User",                                 config_parse_string,                            CONFIG_PARSE_STRING_SAFE,      offsetof(TunTap, user_name)},
      {(char*)0}, {(char*)0},
#line 56 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"NetDev.Name",                              config_parse_ifname,                            0,                             offsetof(NetDev, ifname)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 111 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.Peer",                          config_parse_fou_tunnel_address,                0,                             offsetof(FouTunnel, peer)},
      {(char*)0}, {(char*)0},
#line 201 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.User",                                 config_parse_string,                            CONFIG_PARSE_STRING_SAFE,      offsetof(TunTap, user_name)},
#line 109 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.PeerPort",                      config_parse_ip_port,                           0,                             offsetof(FouTunnel, peer_port)},
#line 108 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.Port",                          config_parse_ip_port,                           0,                             offsetof(FouTunnel, port)},
#line 110 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.Local",                         config_parse_fou_tunnel_address,                0,                             offsetof(FouTunnel, local)},
      {(char*)0}, {(char*)0},
#line 106 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.Protocol",                      config_parse_ip_protocol,                       /* relax= */ true,             offsetof(FouTunnel, fou_protocol)},
#line 131 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXCAN.Peer",                               config_parse_ifname,                            0,                             offsetof(VxCan, ifname_peer)},
#line 134 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.Group",                              config_parse_vxlan_address,                     0,                             offsetof(VxLan, group)},
      {(char*)0}, {(char*)0},
#line 181 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsec.Encrypt",                           config_parse_tristate,                          0,                             offsetof(MACsec, encrypt)},
#line 227 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.UpDelaySec",                          config_parse_sec,                               0,                             offsetof(Bond, updelay)},
#line 135 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.Local",                              config_parse_vxlan_address,                     0,                             offsetof(VxLan, local)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 180 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsec.Port",                              config_parse_macsec_port,                       0,                             0},
      {(char*)0},
#line 133 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.Id",                                 config_parse_uint32,                            0,                             offsetof(VxLan, vni) /* deprecated */},
#line 186 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.Key",            config_parse_macsec_key,                        0,                             0},
      {(char*)0},
#line 185 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.KeyId",          config_parse_macsec_key_id,                     0,                             0},
#line 139 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.MacLearning",                        config_parse_bool,                              0,                             offsetof(VxLan, learning)},
#line 187 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.KeyFile",        config_parse_macsec_key_file,                   0,                             0},
#line 188 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.Activate",       config_parse_macsec_sa_activate,                0,                             0},
      {(char*)0}, {(char*)0},
#line 59 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"NetDev.MACAddress",                        config_parse_netdev_hw_addr,                    ETH_ALEN,                      offsetof(NetDev, hw_addr)},
#line 184 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.PacketNumber",   config_parse_macsec_packet_number,              0,                             0},
#line 107 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"FooOverUDP.Encapsulation",                 config_parse_fou_encap_type,                    0,                             offsetof(FouTunnel, fou_encap_type)},
#line 189 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecTransmitAssociation.UseForEncoding", config_parse_macsec_use_for_encoding,           0,                             0},
      {(char*)0}, {(char*)0},
#line 194 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.Key",             config_parse_macsec_key,                        0,                             0},
#line 190 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.Port",            config_parse_macsec_port,                       0,                             0},
#line 193 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.KeyId",           config_parse_macsec_key_id,                     0,                             0},
#line 57 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"NetDev.Kind",                              config_parse_netdev_kind,                       0,                             offsetof(NetDev, kind)},
#line 195 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.KeyFile",         config_parse_macsec_key_file,                   0,                             0},
#line 196 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.Activate",        config_parse_macsec_sa_activate,                0,                             0},
#line 205 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.MultiQueue",                           config_parse_bool,                              0,                             offsetof(TunTap, multi_queue)},
#line 191 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.MACAddress",      config_parse_macsec_hw_address,                 0,                             0},
#line 74 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPVLAN.Mode",                              config_parse_ipvlan_mode,                       0,                             offsetof(IPVlan, mode)},
#line 192 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveAssociation.PacketNumber",    config_parse_macsec_packet_number,              0,                             0},
#line 253 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BareUDP.DestinationPort",                  config_parse_ip_port,                           0,                             offsetof(BareUDP, dest_port)},
#line 211 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.Mode",                                config_parse_bond_mode,                         0,                             offsetof(Bond, mode)},
#line 157 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.PortRange",                          config_parse_port_range,                        0,                             0},
#line 158 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.DestinationPort",                    config_parse_ip_port,                           0,                             offsetof(VxLan, dest_port)},
#line 161 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.Independent",                        config_parse_bool,                              0,                             offsetof(VxLan, independent)},
#line 144 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.RouteShortCircuit",                  config_parse_bool,                              0,                             offsetof(VxLan, route_short_circuit)},
#line 198 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.MultiQueue",                           config_parse_bool,                              0,                             offsetof(TunTap, multi_queue)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 214 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.AdSelect",                            config_parse_bond_ad_select,                    0,                             offsetof(Bond, ad_select)},
#line 129 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Peer.Name",                                config_parse_ifname,                            0,                             offsetof(Veth, ifname_peer)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 242 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.DefaultPVID",                       config_parse_default_port_vlanid,               0,                             offsetof(Bridge, default_pvid)},
      {(char*)0}, {(char*)0},
#line 76 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPVTAP.Mode",                              config_parse_ipvlan_mode,                       0,                             offsetof(IPVlan, mode)},
#line 136 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.Remote",                             config_parse_vxlan_address,                     0,                             offsetof(VxLan, remote)},
#line 218 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ARPAllTargets",                       config_parse_bond_arp_all_targets,              0,                             offsetof(Bond, arp_all_targets)},
#line 177 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"HSR.Ports",                                config_parse_ifnames,                           IFNAME_VALID_ALTERNATIVE,      offsetof(Hsr, ports)},
#line 58 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"NetDev.MTUBytes",                          config_parse_mtu,                               AF_UNSPEC,                     offsetof(NetDev, mtu)},
      {(char*)0},
#line 178 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"HSR.Protocol",                             config_parse_hsr_protocol,                      0,                             offsetof(Hsr, protocol)},
#line 65 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.ReorderHeader",                       config_parse_tristate,                          0,                             offsetof(VLan, reorder_hdr)},
#line 143 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.L3MissNotification",                 config_parse_bool,                              0,                             offsetof(VxLan, l3miss)},
#line 220 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ResendIGMP",                          config_parse_unsigned,                          0,                             offsetof(Bond, resend_igmp)},
#line 284 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.OriginatorIntervalSec",     config_parse_sec,                               0,                             offsetof(BatmanAdvanced, originator_interval)},
#line 72 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVTAP.Mode",                             config_parse_macvlan_mode,                      0,                             offsetof(MacVlan, mode)},
#line 61 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.Protocol",                            config_parse_vlanprotocol,                      0,                             offsetof(VLan, protocol)},
#line 276 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.DistributedArpTable",       config_parse_bool,                              0,                             offsetof(BatmanAdvanced, distributed_arp_table)},
      {(char*)0},
#line 254 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BareUDP.MinSourcePort",                    config_parse_ip_port,                           0,                             offsetof(BareUDP, min_port)},
#line 68 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVLAN.Mode",                             config_parse_macvlan_mode,                      0,                             offsetof(MacVlan, mode)},
#line 79 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Remote",                            config_parse_tunnel_remote_address,             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 225 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.MinLinks",                            config_parse_unsigned,                          0,                             offsetof(Bond, min_links)},
      {(char*)0}, {(char*)0},
#line 154 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.GroupPolicyExtension",               config_parse_bool,                              0,                             offsetof(VxLan, group_policy)},
      {(char*)0},
#line 243 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.MulticastQuerier",                  config_parse_tristate,                          0,                             offsetof(Bridge, mcast_querier)},
#line 138 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.TTL",                                config_parse_vxlan_ttl,                         0,                             offsetof(VxLan, ttl)},
      {(char*)0},
#line 87 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Mode",                              config_parse_tunnel_mode,                       0,                             offsetof(Tunnel, mode)},
#line 101 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.ERSPANDirection",                   config_parse_erspan_direction,                  0,                             offsetof(Tunnel, erspan_direction)},
#line 165 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.Remote",                            config_parse_geneve_address,                    0,                             offsetof(Geneve, remote)},
#line 275 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.BridgeLoopAvoidance",       config_parse_bool,                              0,                             offsetof(BatmanAdvanced, bridge_loop_avoidance)},
      {(char*)0}, {(char*)0},
#line 173 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.DestinationPort",                   config_parse_ip_port,                           0,                             offsetof(Geneve, dest_port)},
#line 291 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WLAN.WDS",                                 config_parse_tristate,                          0,                             offsetof(WLan, wds)},
      {(char*)0},
#line 287 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPoIB.Mode",                               config_parse_ipoib_mode,                        0,                             offsetof(IPoIB, mode)},
      {(char*)0},
#line 235 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ARPMissedMax",                        config_parse_uint8,                             0,                             offsetof(Bond, arp_missed_max)},
      {(char*)0},
#line 252 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VRF.Table",                                config_parse_vrf_table,                         0,                             offsetof(Vrf, table)},
#line 82 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Key",                               config_parse_tunnel_key,                        0,                             offsetof(Tunnel, key)},
#line 251 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VRF.TableId",                              config_parse_uint32,                            0,                             offsetof(Vrf, table) /* deprecated */},
#line 78 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Local",                             config_parse_tunnel_local_address,              0,                             0},
      {(char*)0},
#line 63 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.MVRP",                                config_parse_tristate,                          0,                             offsetof(VLan, mvrp)},
#line 179 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"HSR.Supervision",                          config_parse_uint8,                             0,                             offsetof(Hsr, supervision)},
#line 237 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.MaxAgeSec",                         config_parse_sec,                               0,                             offsetof(Bridge, max_age)},
#line 64 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.LooseBinding",                        config_parse_tristate,                          0,                             offsetof(VLan, loose_binding)},
#line 277 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.Fragmentation",             config_parse_bool,                              0,                             offsetof(BatmanAdvanced, fragmentation)},
#line 206 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.PacketInfo",                           config_parse_bool,                              0,                             offsetof(TunTap, packet_info)},
#line 247 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.STP",                               config_parse_tristate,                          0,                             offsetof(Bridge, stp)},
#line 217 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ARPValidate",                         config_parse_bond_arp_validate,                 0,                             offsetof(Bond, arp_validate)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 223 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.AllSlavesActive",                     config_parse_bool,                              0,                             offsetof(Bond, all_slaves_active)},
      {(char*)0}, {(char*)0},
#line 153 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.FDBAgeingSec",                       config_parse_sec,                               0,                             offsetof(VxLan, fdb_ageing)},
#line 199 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.PacketInfo",                           config_parse_bool,                              0,                             offsetof(TunTap, packet_info)},
      {(char*)0},
#line 274 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.Aggregation",               config_parse_bool,                              0,                             offsetof(BatmanAdvanced, aggregation)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 159 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.FlowLabel",                          config_parse_flow_label,                        0,                             0},
#line 285 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.RoutingAlgorithm",          config_parse_batadv_routing_algorithm,          0,                             offsetof(BatmanAdvanced, routing_algorithm)},
#line 146 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDPChecksum",                        config_parse_bool,                              0,                             offsetof(VxLan, udpcsum)},
#line 66 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.EgressQOSMaps",                       config_parse_vlan_qos_maps,                     0,                             offsetof(VLan, egress_qos_maps)},
#line 250 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.LinkLocalLearning",                 config_parse_tristate,                          0,                             offsetof(Bridge, linklocal_learn)},
#line 221 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.PacketsPerSlave",                     config_parse_unsigned,                          0,                             offsetof(Bond, packets_per_slave)},
#line 204 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.OneQueue",                             config_parse_warn_compat,                       DISABLED_LEGACY,               0},
      {(char*)0},
#line 137 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.TOS",                                config_parse_unsigned,                          0,                             offsetof(VxLan, tos)},
      {(char*)0},
#line 81 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.TTL",                               config_parse_unsigned,                          0,                             offsetof(Tunnel, ttl)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 197 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.OneQueue",                             config_parse_warn_compat,                       DISABLED_LEGACY,               0},
#line 85 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.DiscoverPathMTU",                   config_parse_tristate,                          0,                             offsetof(Tunnel, pmtudisc)},
#line 224 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.DynamicTransmitLoadBalancing",        config_parse_tristate,                          0,                             offsetof(Bond, tlb_dynamic_lb)},
#line 73 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVTAP.SourceMACAddress",                 config_parse_ether_addrs,                       0,                             offsetof(MacVlan, match_source_mac)},
#line 97 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Encapsulation",                     config_parse_fou_encap_type,                    0,                             offsetof(Tunnel, fou_encap_type)},
#line 278 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.GatewayMode",               config_parse_batadv_gateway_mode,               0,                             offsetof(BatmanAdvanced, gateway_mode)},
      {(char*)0}, {(char*)0},
#line 69 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVLAN.SourceMACAddress",                 config_parse_ether_addrs,                       0,                             offsetof(MacVlan, match_source_mac)},
#line 167 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.TTL",                               config_parse_geneve_ttl,                        0,                             offsetof(Geneve, ttl)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 116 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.Local",                               config_parse_l2tp_tunnel_local_address,         0,                             0},
#line 103 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.SerializeTunneledPackets",          config_parse_tristate,                          0,                             offsetof(Tunnel, gre_erspan_sequence)},
      {(char*)0},
#line 112 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.TunnelId",                            config_parse_l2tp_tunnel_id,                    0,                             offsetof(L2tpTunnel, tunnel_id)},
#line 132 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.VNI",                                config_parse_uint32,                            0,                             offsetof(VxLan, vni)},
#line 238 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.AgeingTimeSec",                     config_parse_sec,                               0,                             offsetof(Bridge, ageing_time)},
#line 257 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.FwMark",                         config_parse_unsigned,                          0,                             offsetof(Wireguard, fwmark) /* deprecated */},
      {(char*)0}, {(char*)0},
#line 246 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.VLANProtocol",                      config_parse_vlanprotocol,                      0,                             offsetof(Bridge, vlan_protocol)},
#line 163 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.VNIFilter",                          config_parse_bool,                              0,                             offsetof(VxLan, vnifilter)},
      {(char*)0}, {(char*)0},
#line 115 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDPDestinationPort",                  config_parse_ip_port,                           0,                             offsetof(L2tpTunnel, l2tp_udp_dport)},
#line 142 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.L2MissNotification",                 config_parse_bool,                              0,                             offsetof(VxLan, l2miss)},
#line 99 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.ERSPANVersion",                     config_parse_erspan_version,                    0,                             offsetof(Tunnel, erspan_version)},
#line 219 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.PrimaryReselectPolicy",               config_parse_bond_primary_reselect,             0,                             offsetof(Bond, primary_reselect)},
      {(char*)0},
#line 55 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"NetDev.Description",                       config_parse_string,                            0,                             offsetof(NetDev, description)},
      {(char*)0},
#line 258 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.ListenPort",                     config_parse_wireguard_listen_port,             0,                             offsetof(Wireguard, port)},
#line 117 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.Remote",                              config_parse_l2tp_tunnel_remote_address,        0,                             0},
#line 145 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDPCheckSum",                        config_parse_bool,                              0,                             offsetof(VxLan, udpcsum)},
      {(char*)0},
#line 80 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.TOS",                               config_parse_unsigned,                          0,                             offsetof(Tunnel, tos)},
#line 130 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Peer.MACAddress",                          config_parse_netdev_hw_addr,                    ETH_ALEN,                      offsetof(Veth, hw_addr_peer)},
#line 262 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.RouteMetric",                    config_parse_wireguard_route_priority,          0,                             offsetof(Wireguard, route_priority)},
      {(char*)0},
#line 222 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.GratuitousARP",                       config_parse_unsigned,                          0,                             offsetof(Bond, num_grat_arp)},
#line 229 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ARPIntervalSec",                      config_parse_sec,                               0,                             offsetof(Bond, arp_interval)},
      {(char*)0}, {(char*)0},
#line 280 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.GatewayBandwithUp",         config_parse_badadv_bandwidth,                  0,                             offsetof(BatmanAdvanced, gateway_bandwidth_up)},
#line 282 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.GatewayBandwidthUp",        config_parse_badadv_bandwidth,                  0,                             offsetof(BatmanAdvanced, gateway_bandwidth_up)},
#line 279 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.GatewayBandwithDown",       config_parse_badadv_bandwidth,                  0,                             offsetof(BatmanAdvanced, gateway_bandwidth_down)},
#line 281 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.GatewayBandwidthDown",      config_parse_badadv_bandwidth,                  0,                             offsetof(BatmanAdvanced, gateway_bandwidth_down)},
      {(char*)0},
#line 113 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.PeerTunnelId",                        config_parse_l2tp_tunnel_id,                    0,                             offsetof(L2tpTunnel, peer_tunnel_id)},
#line 233 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.AdUserPortKey",                       config_parse_ad_user_port_key,                  0,                             offsetof(Bond, ad_user_port_key)},
#line 166 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.TOS",                               config_parse_uint8,                             0,                             offsetof(Geneve, tos)},
#line 47 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Host",                               config_parse_net_condition,                     CONDITION_HOST,                offsetof(NetDev, conditions)},
      {(char*)0},
#line 60 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.Id",                                  config_parse_vlanid,                            0,                             offsetof(VLan, id)},
#line 51 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Version",                            config_parse_net_condition,                     CONDITION_VERSION,             offsetof(NetDev, conditions)},
#line 54 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Firmware",                           config_parse_net_condition,                     CONDITION_FIRMWARE,            offsetof(NetDev, conditions)},
#line 84 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.OutputKey",                         config_parse_tunnel_key,                        0,                             offsetof(Tunnel, okey)},
#line 52 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Credential",                         config_parse_net_condition,                     CONDITION_CREDENTIAL,          offsetof(NetDev, conditions)},
      {(char*)0},
#line 93 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.AllowLocalRemote",                  config_parse_tristate,                          0,                             offsetof(Tunnel, allow_localremote)},
#line 50 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.KernelVersion",                      config_parse_net_condition,                     CONDITION_VERSION,             offsetof(NetDev, conditions)},
#line 261 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.RouteTable",                     config_parse_wireguard_route_table,             0,                             offsetof(Wireguard, route_table)},
#line 128 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TPSession.Name",                         config_parse_l2tp_session_name,                 0,                             0},
#line 94 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.FooOverUDP",                        config_parse_bool,                              0,                             offsetof(Tunnel, fou_tunnel)},
#line 114 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDPSourcePort",                       config_parse_ip_port,                           0,                             offsetof(L2tpTunnel, l2tp_udp_sport)},
      {(char*)0},
#line 48 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Virtualization",                     config_parse_net_condition,                     CONDITION_VIRTUALIZATION,      offsetof(NetDev, conditions)},
#line 273 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Xfrm.Independent",                         config_parse_bool,                              0,                             offsetof(Xfrm, independent)},
#line 75 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPVLAN.Flags",                             config_parse_ipvlan_flags,                      0,                             offsetof(IPVlan, flags)},
      {(char*)0},
#line 263 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.AllowedIPs",                 config_parse_wireguard_allowed_ips,             0,                             0},
      {(char*)0}, {(char*)0},
#line 216 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.ARPIPTargets",                        config_parse_arp_ip_target_address,             0,                             0},
#line 53 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.Architecture",                       config_parse_net_condition,                     CONDITION_ARCHITECTURE,        offsetof(NetDev, conditions)},
#line 62 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.GVRP",                                config_parse_tristate,                          0,                             offsetof(VLan, gvrp)},
      {(char*)0}, {(char*)0},
#line 230 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.LearnPacketIntervalSec",              config_parse_sec,                               0,                             offsetof(Bond, lp_interval)},
#line 269 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.PersistentKeepalive",        config_parse_wireguard_keepalive,               0,                             0},
#line 140 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.ARPProxy",                           config_parse_bool,                              0,                             offsetof(VxLan, arp_proxy)},
      {(char*)0}, {(char*)0},
#line 255 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BareUDP.EtherType",                        config_parse_bare_udp_iftype,                   0,                             offsetof(BareUDP, iftype)},
#line 226 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.MIIMonitorSec",                       config_parse_sec,                               0,                             offsetof(Bond, miimon)},
      {(char*)0},
#line 271 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.RouteMetric",                config_parse_wireguard_peer_route_priority,     0,                             0},
      {(char*)0},
#line 77 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPVTAP.Flags",                             config_parse_ipvlan_flags,                      0,                             offsetof(IPVlan, flags)},
      {(char*)0}, {(char*)0},
#line 240 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.Priority",                          config_parse_uint16,                            0,                             offsetof(Bridge, priority)},
      {(char*)0},
#line 70 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVLAN.BroadcastMulticastQueueLength",    config_parse_macvlan_broadcast_queue_size,      0,                             offsetof(MacVlan, bc_queue_length)},
#line 168 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.UDPChecksum",                       config_parse_bool,                              0,                             offsetof(Geneve, udpcsum)},
      {(char*)0},
#line 249 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.FDBMaxLearned",                     config_parse_bridge_fdb_max_learned,            0,                             offsetof(Bridge, fdb_max_learned)},
#line 160 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.IPDoNotFragment",                    config_parse_df,                                0,                             offsetof(VxLan, df)},
#line 239 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.ForwardDelaySec",                   config_parse_sec,                               0,                             offsetof(Bridge, forward_delay)},
#line 92 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.AssignToLoopback",                  config_parse_bool,                              0,                             offsetof(Tunnel, assign_to_loopback)},
#line 164 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.Id",                                config_parse_geneve_vni,                        0,                             offsetof(Geneve, id)},
#line 141 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.ReduceARPProxy",                     config_parse_bool,                              0,                             offsetof(VxLan, arp_proxy)},
      {(char*)0},
#line 215 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.FailOverMACPolicy",                   config_parse_bond_fail_over_mac,                0,                             offsetof(Bond, fail_over_mac)},
#line 234 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.AdActorSystem",                       config_parse_ad_actor_system,                   0,                             offsetof(Bond, ad_actor_system)},
#line 290 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WLAN.Type",                                config_parse_wlan_iftype,                       0,                             offsetof(WLan, iftype)},
#line 90 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.EncapsulationLimit",                config_parse_encap_limit,                       0,                             0},
      {(char*)0}, {(char*)0},
#line 91 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.Independent",                       config_parse_bool,                              0,                             offsetof(Tunnel, independent)},
      {(char*)0},
#line 170 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.UDP6ZeroChecksumRx",                config_parse_bool,                              0,                             offsetof(Geneve, udp6zerocsumrx)},
#line 232 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.AdActorSystemPriority",               config_parse_ad_actor_sys_prio,                 0,                             offsetof(Bond, ad_actor_sys_prio)},
      {(char*)0}, {(char*)0},
#line 289 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WLAN.PhysicalDevice",                      config_parse_wiphy,                             0,                             0},
#line 245 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.VLANFiltering",                     config_parse_tristate,                          0,                             offsetof(Bridge, vlan_filtering)},
#line 267 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.PresharedKey",               config_parse_wireguard_peer_key,                0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 268 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.PresharedKeyFile",           config_parse_wireguard_peer_key_file,           0,                             0},
      {(char*)0}, {(char*)0},
#line 104 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.ISATAP",                            config_parse_tristate,                          0,                             offsetof(Tunnel, isatap)},
#line 162 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.External",                           config_parse_bool,                              0,                             offsetof(VxLan, external)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 207 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.VNetHeader",                           config_parse_bool,                              0,                             offsetof(TunTap, vnet_hdr)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 286 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPoIB.PartitionKey",                       config_parse_ipoib_pkey,                        0,                             offsetof(IPoIB, pkey)},
#line 236 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.HelloTimeSec",                      config_parse_sec,                               0,                             offsetof(Bridge, hello_time)},
#line 172 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.UDP6ZeroChecksumTx",                config_parse_bool,                              0,                             offsetof(Geneve, udp6zerocsumtx)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 200 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.VNetHeader",                           config_parse_bool,                              0,                             offsetof(TunTap, vnet_hdr)},
#line 283 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"BatmanAdvanced.HopPenalty",                config_parse_uint8,                             0,                             offsetof(BatmanAdvanced, hop_penalty)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 244 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.MulticastSnooping",                 config_parse_tristate,                          0,                             offsetof(Bridge, mcast_snooping)},
      {(char*)0},
#line 119 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDPChecksum",                         config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp_csum)},
#line 256 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.FirewallMark",                   config_parse_unsigned,                          0,                             offsetof(Wireguard, fwmark)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 213 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.LACPTransmitRate",                    config_parse_bond_lacp_rate,                    0,                             offsetof(Bond, lacp_rate)},
      {(char*)0}, {(char*)0},
#line 270 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.RouteTable",                 config_parse_wireguard_peer_route_table,        0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 96 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.FOUSourcePort",                     config_parse_ip_port,                           0,                             offsetof(Tunnel, encap_src_port)},
#line 169 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.UDP6ZeroCheckSumRx",                config_parse_bool,                              0,                             offsetof(Geneve, udp6zerocsumrx)},
      {(char*)0},
#line 228 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.DownDelaySec",                        config_parse_sec,                               0,                             offsetof(Bond, downdelay)},
#line 241 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.GroupForwardMask",                  config_parse_uint16,                            0,                             offsetof(Bridge, group_fwd_mask)},
#line 209 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.Group",                                config_parse_string,                            CONFIG_PARSE_STRING_SAFE,      offsetof(TunTap, group_name)},
#line 155 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.GenericProtocolExtension",           config_parse_bool,                              0,                             offsetof(VxLan, generic_protocol_extension)},
      {(char*)0}, {(char*)0},
#line 49 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Match.KernelCommandLine",                  config_parse_net_condition,                     CONDITION_KERNEL_COMMAND_LINE, offsetof(NetDev, conditions)},
#line 95 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.FOUDestinationPort",                config_parse_ip_port,                           0,                             offsetof(Tunnel, fou_destination_port)},
      {(char*)0},
#line 175 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.FlowLabel",                         config_parse_geneve_flow_label,                 0,                             0},
      {(char*)0}, {(char*)0},
#line 202 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.Group",                                config_parse_string,                            CONFIG_PARSE_STRING_SAFE,      offsetof(TunTap, group_name)},
#line 105 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.External",                          config_parse_bool,                              0,                             offsetof(Tunnel, external)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 121 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDP6ChecksumRx",                      config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp6_csum_rx)},
#line 126 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TPSession.PeerSessionId",                config_parse_l2tp_session_id,                   0,                             0},
      {(char*)0},
#line 248 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bridge.MulticastIGMPVersion",              config_parse_bridge_igmp_version,               0,                             offsetof(Bridge, igmp_version)},
      {(char*)0}, {(char*)0},
#line 171 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.UDP6ZeroCheckSumTx",                config_parse_bool,                              0,                             offsetof(Geneve, udp6zerocsumtx)},
#line 125 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TPSession.SessionId",                    config_parse_l2tp_session_id,                   0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 152 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.RemoteChecksumRx",                   config_parse_bool,                              0,                             offsetof(VxLan, remote_csum_rx)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 120 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDPCheckSum",                         config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp_csum) /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 123 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDP6ChecksumTx",                      config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp6_csum_tx)},
      {(char*)0}, {(char*)0},
#line 264 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.Endpoint",                   config_parse_wireguard_endpoint,                0,                             0},
      {(char*)0}, {(char*)0},
#line 210 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tap.KeepCarrier",                          config_parse_bool,                              0,                             offsetof(TunTap, keep_fd)},
#line 272 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Xfrm.InterfaceId",                         config_parse_uint32,                            0,                             offsetof(Xfrm, if_id)},
      {(char*)0},
#line 102 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.ERSPANHardwareId",                  config_parse_erspan_hwid,                       0,                             offsetof(Tunnel, erspan_hwid)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 151 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.RemoteChecksumTx",                   config_parse_bool,                              0,                             offsetof(VxLan, remote_csum_tx)},
#line 156 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.MaximumFDBEntries",                  config_parse_unsigned,                          0,                             offsetof(VxLan, max_fdb)},
      {(char*)0},
#line 203 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tun.KeepCarrier",                          config_parse_bool,                              0,                             offsetof(TunTap, keep_fd)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 122 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDP6CheckSumRx",                      config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp6_csum_rx) /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 89 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.CopyDSCP",                          config_parse_bool,                              0,                             offsetof(Tunnel, copy_dscp)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 288 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"IPoIB.IgnoreUserspaceMulticastGroups",     config_parse_tristate,                          0,                             offsetof(IPoIB, umcast)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 259 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.PrivateKey",                     config_parse_wireguard_private_key,             0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 124 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.UDP6CheckSumTx",                      config_parse_bool,                              0,                             offsetof(L2tpTunnel, udp6_csum_tx) /* deprecated */},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 88 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.IPv6FlowLabel",                     config_parse_ipv6_flowlabel,                    0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 83 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.InputKey",                          config_parse_tunnel_key,                        0,                             offsetof(Tunnel, ikey)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 148 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDP6ZeroChecksumRx",                 config_parse_bool,                              0,                             offsetof(VxLan, udp6zerocsumrx)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 71 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACVLAN.BroadcastQueueThreshold",          config_parse_macvlan_broadcast_queue_threshold, 0,                             offsetof(MacVlan, bc_queue_threshold)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 182 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveChannel.Port",                config_parse_macsec_port,                       0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 150 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDP6ZeroChecksumTx",                 config_parse_bool,                              0,                             offsetof(VxLan, udp6zerocsumtx)},
      {(char*)0}, {(char*)0},
#line 176 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.InheritInnerProtocol",              config_parse_bool,                              0,                             offsetof(Geneve, inherit_inner_protocol)},
#line 100 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.ERSPANIndex",                       config_parse_erspan_index,                      0,                             offsetof(Tunnel, erspan_index)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 86 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.IgnoreDontFragment",                config_parse_bool,                              0,                             offsetof(Tunnel, ignore_df)},
      {(char*)0},
#line 174 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"GENEVE.IPDoNotFragment",                   config_parse_geneve_df,                         0,                             offsetof(Geneve, geneve_df)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 147 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDP6ZeroCheckSumRx",                 config_parse_bool,                              0,                             offsetof(VxLan, udp6zerocsumrx)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 118 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TP.EncapsulationType",                   config_parse_l2tp_encap_type,                   0,                             offsetof(L2tpTunnel, l2tp_encap_type)},
      {(char*)0},
#line 149 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VXLAN.UDP6ZeroCheckSumTx",                 config_parse_bool,                              0,                             offsetof(VxLan, udp6zerocsumtx)},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 265 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.PublicKey",                  config_parse_wireguard_peer_key,                0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 212 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.TransmitHashPolicy",                  config_parse_bond_xmit_hash_policy,             0,                             offsetof(Bond, xmit_hash_policy)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 98 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Tunnel.IPv6RapidDeploymentPrefix",         config_parse_6rd_prefix,                        0,                             0},
#line 231 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"Bond.PeerNotifyDelaySec",                  config_parse_sec,                               0,                             offsetof(Bond, peer_notify_delay)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 67 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"VLAN.IngressQOSMaps",                      config_parse_vlan_qos_maps,                     0,                             offsetof(VLan, ingress_qos_maps)},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0},
#line 183 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"MACsecReceiveChannel.MACAddress",          config_parse_macsec_hw_address,                 0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
#line 260 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuard.PrivateKeyFile",                 config_parse_wireguard_private_key_file,        0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0},
#line 266 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"WireGuardPeer.PublicKeyFile",              config_parse_wireguard_peer_key_file,           0,                             0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0}, {(char*)0},
      {(char*)0}, {(char*)0}, {(char*)0},
#line 127 "../systemd/src/network/netdev/netdev-gperf.gperf"
      {"L2TPSession.Layer2SpecificHeader",         config_parse_l2tp_session_l2spec,               0,                             0}
    };
#if (defined __GNUC__ && __GNUC__ + (__GNUC_MINOR__ >= 6) > 4) || (defined __clang__ && __clang_major__ >= 3)
#pragma GCC diagnostic pop
#endif

  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register unsigned int key = network_netdev_gperf_hash (str, len);

      if (key <= MAX_HASH_VALUE)
        {
          register const char *s = wordlist[key].section_and_lvalue;

          if (s && *str == *s && !strcmp (str + 1, s + 1))
            return &wordlist[key];
        }
    }
  return (struct ConfigPerfItem *) 0;
}
